@@ -5,6 +5,7 @@ from elftools.dwarf.locationlists import LocationParser, LocationExpr
 from elftools.dwarf.dwarf_expr import DWARFExprParser, DWARFExprOp, DW_OP_opcode2name
 from elftools.dwarf.descriptions import _DESCR_DW_LANG, _DESCR_DW_ATE, _DESCR_DW_ACCESS, _DESCR_DW_INL, _REG_NAMES_x86, _REG_NAMES_x64
 from elftools.common.exceptions import ELFParseError
+from elftools.dwarf.ranges import BaseAddressEntry as RangeBaseAddressEntry
 from .dwarfone import DWARFExprParserV1
 
 MAX_INLINE_BYTEARRAY_LEN = 32
@@ -79,6 +80,20 @@ def get_cu_base(die):
     elif 'DW_AT_entry_pc' in top_die.attributes:
         return top_die.attributes['DW_AT_entry_pc'].value
     # TODO: ranges?
+    elif 'DW_AT_ranges' in top_die.attributes:
+        di = die.dwarfinfo
+        if not di._ranges:
+            di._ranges = di.range_lists()
+        if not di._ranges: # Absent in the DWARF file
+            raise NoBaseError()
+        rl = di._ranges.get_range_list_at_offset(top_die.attributes['DW_AT_ranges'].value)
+        base = None
+        for r in rl:
+            if isinstance(r, RangeBaseAddressEntry) and (base is None or r.base_address < base):
+                base = r.base_address
+        if base is None:
+            raise NoBaseError()
+        return base
     else:
         raise NoBaseError()
 
@@ -248,7 +263,7 @@ class DIETableModel(QAbstractTableModel):
             if form == 'DW_FORM_addr' and isinstance(val, int):
                 return hex(val)
             elif form == 'DW_FORM_flag_present':
-                return ''
+                return 'True'
             elif form in ('DW_FORM_ref0', 'DW_FORM_ref1', 'DW_FORM_ref2', 'DW_FORM_ref4', 'DW_FORM_ref8', 'DW_FORM_ref_addr'):
                 return "Ref: 0x%x" % val # There are several other reference forms in the spec
             elif form == 'DW_FORM_flag':
@@ -538,7 +553,9 @@ def ip_in_range(die, ip):
         cu_base = get_cu_base(die)
         rl = di._ranges.get_range_list_at_offset(die.attributes['DW_AT_ranges'].value)
         for r in rl:
-            if r.begin_offset <= ip - cu_base < r.end_offset:
+            if isinstance(r, RangeBaseAddressEntry):
+                cu_base = r.base_address
+            elif r.begin_offset <= ip - cu_base < r.end_offset:
                 return True
     if 'DW_AT_low_pc' in die.attributes and 'DW_AT_high_pc' in die.attributes:
         l = die.attributes['DW_AT_low_pc'].value
